@@ -20,8 +20,8 @@ use base 'PDF::Builder::Basic::PDF::String';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -29,30 +29,36 @@ PDF::Builder::Basic::PDF::Number - Numbers in PDF. Inherits from L<PDF::Builder:
 
 =head1 METHODS
 
+=head2 convert
+
+    $n->convert($str)
+
 =over
 
-=item $n->convert($str)
-
 Converts a string from PDF to internal, by doing nothing
 
+=back
+
 =cut
 
 sub convert {
     return $_[1];
 }
 
-=item $n->as_pdf()
+=head2 as_pdf
+
+    $n->as_pdf()
+
+=over
 
 Converts a number to PDF format
 
+=back
+
 =cut
 
 sub as_pdf {
     return $_[0]->{'val'};
 }
 
-=back
-
-=cut
-
 1;
