@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::ColorSpace';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Util;
@@ -16,6 +16,16 @@ use Scalar::Util qw(weaken);
 
 PDF::Builder::Resource::ColorSpace::Indexed - base colorspace support for indexed color models. Inherits from L<PDF::Builder::Resource::ColorSpace>
 
+=head2 new
+
+    PDF::Builder::Resource::ColorSpace::Indexed->new($pdf, $key, %opts)
+
+=over
+
+Create a new Indexed ColorSpace object.
+
+=back
+
 =cut
 
 sub new {
@@ -33,6 +43,8 @@ sub new {
     return $self;
 }
 
+# unknown -- not used anywhere
+
 sub enumColors {
     my $self = shift;
 
@@ -45,6 +57,8 @@ sub enumColors {
     return %col;
 }
 
+# unknown -- not used anywhere
+
 sub nameColor {
     my ($self, $n) = @_;
 
@@ -54,6 +68,8 @@ sub nameColor {
     return $k;
 }
 
+# unknown -- not used anywhere
+
 sub resolveNearestRGB {
     my $self = shift;
     my ($r, $g, $b) = @_; # need to be in 0-255
