@@ -3,8 +3,8 @@ package PDF::Builder::Resource::XObject::Image::TIFF::File;
 use strict;
 use warnings;
 
-our $VERSION = '3.024'; # VERSION
-our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use IO::File;
 
@@ -12,6 +12,19 @@ use IO::File;
 
 PDF::Builder::Resource::XObject::Image::TIFF::File - support routines for TIFF image library
 
+=head1 METHODS
+
+=head2 new
+
+    PDF::Builder::Resource::XObject::Image::TIFF::File->new()
+
+=over
+
+Create a TIFF image object, I<not> using the Graphics::TIFF library.
+Remember to use the Builder.pm method image_tiff.
+
+=back
+
 =cut
 
 sub new {
